@@ -27,7 +27,7 @@ dialogId("disk-v-tezko", "font_big", "It will be difficult.")
 dialogStr("Dat wordt lastig.")
 
 
-dialogId("disk-v-nejde", "font_big", "I don't think it can be done. Why would they be hiding it here, if we could lift it?")
+dialogId("disk-v-nejde", "font_big", "I don’t think it can be done. Why would they be hiding it here, if we could lift it?")
 dialogStr("Ik denk niet dat het gaat lukken. Waarom zouden ze het hier verstoppen als we het makkelijk op konden tillen?")
 
 
@@ -88,7 +88,7 @@ dialogStr("Bah. Monstertjes.")
 
 
 dialogId("disk-v-pozor", "font_big", "Above all, we must be careful not to take them with the disk. The player wouldn’t be happy if we pour them on their desktop.")
-dialogStr("We moeten wel voorzichtig zijn en ze niet perongeluk meenemen. De speler zou niet blij zijn als die op zijn of haar computer belanden.")
+dialogStr("We moeten wel voorzichtig zijn en ze niet per ongeluk meenemen. De speler zou niet blij zijn als die op zijn of haar computer belanden.")
 
 
 dialogId("disk-m-ukol", "font_small", "Our goal is to push out that disk.")
