@@ -979,6 +979,22 @@ worldmap_addDesc("score", "sv", "Specialpoäng", "")
 worldmap_addDesc("score", "pt_BR", "Pontuação Especial", "")
 worldmap_addDesc("score", "ru", "Специальный счёт", "")
 
+worldmap_addDesc("hanoi", "en", "Separated", "Branch of New Generation")
+worldmap_addDesc("hanoi", "de", "Getrennt", "Zweig der neuen Generation")
+worldmap_addDesc("hanoi", "cs", "Odděleni", "Větev Nové Generace")
+worldmap_addDesc("hanoi", "sv", "Separerade", "Gren av en ny generation")
+worldmap_addDesc("hanoi", "nl", "Uitelkaar", "Tak van de nieuwe generatie")
+worldmap_addDesc("hanoi", "bg", "Разделени", "Нова генерация")
+worldmap_addDesc("hanoi", "ru", "Отделение", "Новая ветвь в NG")
+
+worldmap_addDesc("rush", "en", "Filled Car Park", "Branch of New Generation")
+worldmap_addDesc("rush", "de", "Voller Parkplatz", "Zweig der neuen Generation")
+worldmap_addDesc("rush", "cs", "Zaplněné parkoviště", "Větev Nové Generace")
+worldmap_addDesc("rush", "sv", "Full parkering", "Gren av en ny generation")
+worldmap_addDesc("rush", "nl", "Volle parkeerplek", "Tak van de nieuwe generatie")
+worldmap_addDesc("rush", "bg", "Запълнен паркинг", "Нова генерация")
+worldmap_addDesc("rush", "ru", "Полная стоянка", "Новая ветвь в NG")
+
 worldmap_addDesc("fdto", "en", "FDTO Building", "Branch of New Generation")
 worldmap_addDesc("fdto", "cs", "Budova FDTO", "Větev Nové generace")
 worldmap_addDesc("fdto", "de", "Haus FDTO", "Zweig der neuen Generation")
@@ -990,6 +1006,22 @@ worldmap_addDesc("fdto", "sl", "Zgradba RDA", "NG")
 worldmap_addDesc("fdto", "pt_BR", "Casa FDTO?", "NG")
 worldmap_addDesc("fdto", "ru", "Здание FDTO", "Новая ветвь в NG")
 
+worldmap_addDesc("rotate", "en", "Rotate It", "Branch of New Generation")
+worldmap_addDesc("rotate", "de", "Dreh es", "Zweig der neuen Generation")
+worldmap_addDesc("rotate", "cs", "Roztočte to", "Větev Nové generace")
+worldmap_addDesc("rotate", "sv", "Rotera den", "Gren av en ny generation")
+worldmap_addDesc("rotate", "nl", "Draai Het", "Gren av en ny generation")
+worldmap_addDesc("rotate", "bg", "Завъртете това", "Нова генерация")
+worldmap_addDesc("rotate", "ru", "Поверните это", "Новая ветвь в NG")
+
+worldmap_addDesc("nowall", "en", "No Wall at All", "Branch of New Generation")
+worldmap_addDesc("nowall", "de", "Keine Wände", "Zweig der neuen Generation")
+worldmap_addDesc("nowall", "cs", "Vůbec žádná zeď", "Větev Nové Generace")
+worldmap_addDesc("nowall", "sv", "Inga väggar alls", "Gren av en ny generation")
+worldmap_addDesc("nowall", "nl", "Helemaal geen muren", "Tak van de nieuwe generatie")
+worldmap_addDesc("nowall", "bg", "Съвсем без стени", "Нова генерация")
+worldmap_addDesc("nowall", "ru", "Нигде нет стен.", "Новая ветвь в NG")
+
 worldmap_addDesc("hole", "en", "Hard Hole", "Branch of New Generation")
 worldmap_addDesc("hole", "de", "Tiefer Graben", "Zweig der neuen Generation")
 worldmap_addDesc("hole", "cs", "Nepříjemná propast", "Větev Nové generace")
@@ -1014,38 +1046,6 @@ worldmap_addDesc("keys", "nl", "Slotenmakerij", "Tak van de nieuwe generatie")
 worldmap_addDesc("keys", "bg", "Ключарница", "Нова генерация")
 worldmap_addDesc("keys", "ru", "Слесарь", "Новая ветвь в NG")
 
-worldmap_addDesc("hanoi", "en", "Separated", "Branch of New Generation")
-worldmap_addDesc("hanoi", "de", "Getrennt", "Zweig der neuen Generation")
-worldmap_addDesc("hanoi", "cs", "Odděleni", "Větev Nové Generace")
-worldmap_addDesc("hanoi", "sv", "Separerade", "Gren av en ny generation")
-worldmap_addDesc("hanoi", "nl", "Uitelkaar", "Tak van de nieuwe generatie")
-worldmap_addDesc("hanoi", "bg", "Разделени", "Нова генерация")
-worldmap_addDesc("hanoi", "ru", "Отделение", "Новая ветвь в NG")
-
-worldmap_addDesc("rush", "en", "Filled Car Park", "Branch of New Generation")
-worldmap_addDesc("rush", "de", "Voller Parkplatz", "Zweig der neuen Generation")
-worldmap_addDesc("rush", "cs", "Zaplněné parkoviště", "Větev Nové Generace")
-worldmap_addDesc("rush", "sv", "Full parkering", "Gren av en ny generation")
-worldmap_addDesc("rush", "nl", "Volle parkeerplek", "Tak van de nieuwe generatie")
-worldmap_addDesc("rush", "bg", "Запълнен паркинг", "Нова генерация")
-worldmap_addDesc("rush", "ru", "Полная стоянка", "Новая ветвь в NG")
-
-worldmap_addDesc("nowall", "en", "No Wall at All", "Branch of New Generation")
-worldmap_addDesc("nowall", "de", "Keine Wände", "Zweig der neuen Generation")
-worldmap_addDesc("nowall", "cs", "Vůbec žádná zeď", "Větev Nové Generace")
-worldmap_addDesc("nowall", "sv", "Inga väggar alls", "Gren av en ny generation")
-worldmap_addDesc("nowall", "nl", "Helemaal geen muren", "Tak van de nieuwe generatie")
-worldmap_addDesc("nowall", "bg", "Съвсем без стени", "Нова генерация")
-worldmap_addDesc("nowall", "ru", "Нигде нет стен.", "Новая ветвь в NG")
-
-worldmap_addDesc("rotate", "en", "Rotate It", "Branch of New generation")
-worldmap_addDesc("rotate", "de", "Dreh es", "Zweig der neuen Generation")
-worldmap_addDesc("rotate", "cs", "Roztočte to", "Větev Nové generace")
-worldmap_addDesc("rotate", "sv", "Rotera den", "Gren av en ny generation")
-worldmap_addDesc("rotate", "nl", "Draai Het", "Gren av en ny generation")
-worldmap_addDesc("rotate", "bg", "Завъртете това", "Нова генерация")
-worldmap_addDesc("rotate", "ru", "Поверните это", "Новая ветвь в NG")
-
 worldmap_addDesc("linux", "en", "Linuxers Must Be Mad", "Branch of New Generation")
 worldmap_addDesc("linux", "de", "Linuxbenutzer müssen verrückt sein", "Zweig der neuen Generation")
 worldmap_addDesc("linux", "cs", "Linuxáci musí být šílení", "Větev Nové Generace")
