@@ -16,7 +16,7 @@ node_bestSolution("viking1", 119, "Pavel Danihelka")
 node_bestSolution("airplane", 235, "Johannes Drescher")
 node_bestSolution("bathyscaph", 82, "Pavel Danihelka")
 node_bestSolution("tank", 402, "Josef Peterka")
-node_bestSolution("viking2", 349, "Gabor Braun")
+node_bestSolution("viking2", 341, "Uoti Urpala")
 node_bestSolution("party2", 283, "Gabor Braun")
 node_bestSolution("gods", 537, "Masaaki Irie")
  
@@ -83,6 +83,9 @@ node_bestSolution("rush", 852, "Miroslav Olšák")
 node_bestSolution("fdto", 251, "Ronny Standtke")
 node_bestSolution("rotate", 213, "Masaaki Irie")
 node_bestSolution("nowall", 418, "Masaaki Irie")
-node_bestSolution("hole", 499, "Miroslav Olšák")
-node_bestSolution("key", 834, "Masaaki Irie")
+node_bestSolution("hole", 465, "Brian Raiter")
+node_bestSolution("key", 596, "Brian Raiter")
 node_bestSolution("keys", 283, "Masaaki Irie")
+node_bestSolution("linux", 663, "Masaaki Irie")
+
+node_bestSolution("electromagnet", 482, "Josef Peterka")
